/*
 * Ch6b_CreateSession.sql
 * Copyright 2001 Matthew J. Holmes
 */

IF EXISTS (SELECT * FROM sysObjects WHERE ID = Object_Id('Ch6b_CreateSession'))
	DROP PROC Ch6b_CreateSession
GO

CREATE PROC Ch6b_CreateSession
	@Name		VARCHAR50, 
	@Password	VARCHAR50, 
	@Device		VARCHAR50
AS
	DECLARE @SID	int
	DECLARE @UID	int
	DECLARE @RID	int
	DECLARE @PWD	varchar(50)
	DECLARE @Access	datetime

	/* Find the user and password */ 
	SELECT @UID = U.UID, @PWD = U.Password FROM tbUser U WHERE U.Name = @Name
	IF @UID IS NULL RETURN 1
	IF @PWD <> @Password RETURN 2

	/* Find the radio */
	SELECT @RID = R.RID FROM tbRadio R WHERE R.Device = @Device
	IF @RID IS NULL RETURN 3

	/* Remove old sessions */
	DELETE tbSession WHERE DATEDIFF(HOUR, LastAccess, GETDATE()) >= 4

	/* Radio in another session with a different user? */
	SELECT @SID = S.SID FROM tbSession S WHERE S.RID = @RID AND S.UID <> @UID
	IF @SID IS NOT NULL RETURN 4

	/* User in another session with a different radio? */
	SELECT @SID = S.SID FROM tbSession S WHERE S.UID = @UID AND S.RID <> @RID 
	IF @SID IS NOT NULL RETURN 5

	/* OK so far. Assume user logging in again, or start new session */
	SELECT @SID = S.SID FROM tbSession S WHERE S.RID = @RID AND S.UID = @UID
	IF @SID IS NOT NULL
		UPDATE tbSession SET LastAccess = GETDATE(), RID = @RID WHERE SID = @SID
	ELSE
		INSERT tbSession VALUES (@RID, @UID, GETDATE(), CONVERT(varchar(50), NEWID()))

	RETURN 0
GO