// Define this so we don't use the Palm OS pre-compiled headers.
// We can't use them here because we re-define some build options
#ifndef PILOT_PRECOMPILED_HEADERS_OFF
#define	PILOT_PRECOMPILED_HEADERS_OFF
#endif

// Define EMULATION_LEVEL.  __PALMOS_TRAPS__ was pre-defined by MW C Compiler
// Test it before we blow it away so we can properly define EMULATION_LEVEL.
#if __PALMOS_TRAPS__
		#define EMULATION_LEVEL		EMULATION_NONE		// building Pilot executable
#endif


// Now clear __PALMOS_TRAPS__ and define USE_TRAPS so headers do the right thing
// That is, we need to be able to get the addresses of SampleLibrary routines.
// Other modules will access the routines through traps.
#undef __PALMOS_TRAPS__
#define __PALMOS_TRAPS__ 	0
#define	USE_TRAPS 	0

// Include Pilot headers
#include <PalmOS.h>


// Our library public definitions (library API)
#include "DBSLib.h"

//Out library's memory management functions
#include "DBSLibMem.h"


#define DBSLibInstall __Startup__

/*********************************
 * Local function prototypes
 *********************************/
//Installation entry point - called when an application loads the library
//for the first time
Err DBSLibInstall(UInt16 refNum, SysLibTblEntryPtr entryP);

//Function which returns our dispatch table
static MemPtr	asm DBSLibDispatchTable(void);

Err DBSLibInstall(UInt16 refNum, SysLibTblEntryPtr entryP)
{
   //Assign our library dispatch table's address to the
   //pointer to the library dispatch table
   entryP->dispatchTblP = (MemPtr*)DBSLibDispatchTable();
	
   //Initialize the globals pointer to 0
   entryP->globalsP = NULL;
	
   return errNone;
}


#define prvJmpSize		4                 //# of bytes in a JMP instruction


// Now, define a macro for offset list entries
#define libDispatchEntry(index)		(kOffset+((index)*prvJmpSize))


// Finally, define the size of the dispatch table's offset list --
// it is equal to the size of each entry (which is presently 2 bytes) times
// the number of entries in the offset list (***including the @Name entry***).
//
#define numFunctions   8       //0 based number of functions in table
#define	kOffset		(2*numFunctions)		// NOTE: This is empirical!!!!!!
														// Will change when table changes!!


static MemPtr	asm DBSLibDispatchTable(void)
{
	LEA		@Table, A0								// table ptr
	RTS													// exit with it

@Table:
	// Offset to library name
	DC.W		@Name
	
	//
	// Library function dispatch entries
	//
	// ***IMPORTANT***
	// The index parameters passed to the macro libDispatchEntry
	// must be numbered consecutively, beginning with zero.
	//
	// The hard-wired values need to be used for offsets because the MW SDK tools do
	// not support label subtraction.
	//
	
	// Standard traps
	DC.W		libDispatchEntry(0)					// Open
	DC.W		libDispatchEntry(1)					// Close
	DC.W		libDispatchEntry(2)					// Sleep
	DC.W		libDispatchEntry(3)					// Wake
	
	// Start of the Custom traps
	DC.W     libDispatchEntry(4)              //GetAPIVersion
	DC.W		libDispatchEntry(5)					//ParseSchema
	DC.W     libDispatchEntry(6)              //GetDBInfo

// Standard library function handlers
@GotoOpen:
	JMP 		DBSLibOpen
@GotoClose:
	JMP 		DBSLibClose
@GotoSleep:
	JMP 		DBSLibSleep
@GotoWake:
	JMP 		DBSLibWake
	
// Custom library function handlers
@GotoGetAPIVersion:
   JMP      DBSLibGetAPIVersion
@GotoParseSchema:
	JMP		DBSLibParseSchema
	
@GotoGetDBInfo:
   JMP      DBSLibGetDBInfo
	
@Name:
	DC.B		dbsLibName							// This name identifies the library.  Apps
															// can pass it to SysLibFind() to check if the
															// library is already installed
	
}
