#ifndef __DBS_LIB_H__
#define __DBS_LIB_H__

// Palm OS common definitions
#include <PalmOS.h>
#include <PalmTypes.h>
#include <SystemResources.h>


//Type and creator of DBSLib
#define dbsLibCreatorID 'DBSL'
#define dbsLibTypeID   'libr'


//Internal library name which can be passed to SysLibFind()
#define dbsLibName      "DBSLib.lib"

#define dbsLibErrParam       (appErrorClass | 1)
#define dbsLibErrNotOpen     (appErrorClass | 2)
#define dbsLibErrStillOpen   (appErrorClass | 3)

#define dbsLibErrMemory      (appErrorClass | 4)

#define dbsLibErrParse       (appErrorClass | 5)

#define dbsLibErrArg        (appErrorClass | 6)

#define dbsLibErrDB          (appErrorClass | 7)

#define dbsLibErrState      (appErrorClass | 8)



//-----------------------------------------------------------------------------
// Sample library function trap ID's. Each library call gets a trap number:
//   sampleLibTrapXXXX which serves as an index into the library's dispatch table.
//   The constant sysLibTrapCustom is the first available trap number after
//   the system predefined library traps Open,Close,Sleep & Wake.
//
// WARNING!!! The order of these traps MUST match the order of the dispatch
//  table in SampleLibDispatch.c!!!
//-----------------------------------------------------------------------------

typedef enum
{
   sysLibTrapAPIVersion = sysLibTrapCustom,
   dbsLibTrapParseSchema,	
   dbsLibTrapGetSchema,
   dbsLibTrapLast
}DBSLibTrapEnum;


//--------------------------------------------------
// Standard library open, close, sleep and wake functions
//--------------------------------------------------

#define DB_NAME_LEN 64
#define DB_SCHEMA_LEN 128


extern Err DBSLibOpen(UInt16 refNum, UInt32 * clientContextPtr)
				SYS_TRAP(sysLibTrapOpen);
				
extern Err DBSLibClose(UInt16 refNum, UInt32 clientContext)
				SYS_TRAP(sysLibTrapClose);

extern Err DBSLibSleep(UInt16 refNum)
				SYS_TRAP(sysLibTrapSleep);

extern Err DBSLibWake(UInt16 refNum)
				SYS_TRAP(sysLibTrapWake);
				
extern Err DBSLibGetAPIVersion(UInt16 refNum, UInt32 *pVer)
                SYS_TRAP(sysLibTrapAPIVersion);
				                
extern Err DBSLibParseSchema(UInt16 refNum, UInt32 clientContext, Char* pszXMLSchema, Boolean bDeleteDB)
                SYS_TRAP(dbsLibTrapParseSchema);
                
extern Err DBSLibGetDBInfo(UInt16 refNum, UInt32 clientContext, Char* pszName, Int16 *pnNumRecs, Int16 *pnNumFields, Char* pszSchema)
                SYS_TRAP(dbsLibTrapGetSchema);				

#endif //__DBS_LIB_H__